References — pysal v25.7rc1 Manual

Skip to main content
`Ctrl`+`K`

# References

[AR14]

Luc Anselin and Sergio J. Rey. Modern Spatial Econometrics in Practice: A Guide to GeoDa, GeoDaSpace and PySAL. GeoDa Press, 2014.

[CRKW19]

Renan Xavier Cortes, Sergio Rey, Elijah Knaap, and Levi John Wolf. An open-source framework for non-spatial and spatial segregation measures: the PySAL segregation module. Journal of Computational Social Science, November 2019. doi:10.1007/s42001-019-00059-3.

[FBG+22]

Xin Feng, Germano Barcelos, James D. Gaboardi, Elijah Knaap, Ran Wei, Levi J. Wolf, Qunshan Zhao, and Sergio J. Rey. Spopt: a python package for solving spatial optimization problems in pysal. Journal of Open Source Software, 7(74):3330, 2022. URL: https://doi.org/10.21105/joss.03330, doi:10.21105/joss.03330.

[Fle19]

Martin Fleischmann. Momepy: urban morphology measuring toolkit. Journal of Open Source Software, 4(43):1807, 2019. doi:10.21105/joss.01807.

[FYK17]

A. Stewart Fotheringham, Wenbai Yang, and Wei Kang. Multiscale geographically weighted regression (MGWR). Annals of the American Association of Geographers, pages 1247–1265, 2017. doi:10.1080/24694452.2017.1352480.

[GRL21]

James D. Gaboardi, Sergio Rey, and Stefanie Lumnitz. Spaghetti: spatial network analysis in pysal. Journal of Open Source Software, 6(62):2826, 2021. URL: https://doi.org/10.21105/joss.02826, doi:10.21105/joss.02826.

[LABC+20]

Stefanie Lumnitz, Dani Arribas-Bell, Renan X. Cortes, James D. Gaboardi, Verena Griess, Wei Kang, Taylor M. Oshan, Levi Wolf, and Sergio Rey. `splot` - visual analytics for spatial statistics. Journal of Open Source Software, 5(47):1882, 2020. URL: https://doi.org/10.21105/joss.01882, doi:10.21105/joss.01882.

[RHK+20]

Sergio Rey, Su Yeon Han, Wei Kang, Elijah Knaap, and Renan Xavier Cortes. A Visual Analytics System for Space–Time Dynamics of Regional Income Distributions Utilizing Animated Flow Maps and Rank-based Markov Chains. Geographical Analysis, 52(4):537–557, 2020. doi:10.1111/gean.12239.

[Rey14]

Sergio J. Rey. Python Spatial Analysis Library (PySAL): An update and illustration. In C. Brunsdon and A. SIngleton, editors, Geocomputation. Sage, London, 2014.

[Rey19]

Sergio J. Rey. PySAL: The first 10 years. Spatial Economic Analysis, 14(3):273–282, July 2019. doi:10.1080/17421772.2019.1593495.

[RA07]

Sergio J. Rey and Luc Anselin. PySAL: A Python Library of Spatial Analytical Methods. The Review of Regional Studies, 37(1):5–27, 2007.

[RAA+22]

Sergio J. Rey, Luc Anselin, Pedro Amaral, Dani Arribas-Bel, Renan Xavier Cortes, James David Gaboardi, Wei Kang, Elijah Knaap, Ziqi Li, Stefanie Lumnitz, Taylor M. Oshan, Hu Shao, and Levi John Wolf. The PySAL Ecosystem: Philosophy and Implementation. Geographical Analysis, 54(3):467–487, 2022. doi:10.1111/gean.12276.

[RCK21]

Sergio J. Rey, Renan Cortes, and Elijah Knaap. Comparative spatial segregation analytics. Spatial Demography, 9:31–56, January 2021. doi:10.1007/s40980-021-00075-w.

[RArribasBelW23]

Sergio J. Rey, Dani Arribas-Bel, and Levi John Wolf. Geographic Data Science with Python. Chapman & Hall/CRC Texts in Statistical Science. CRC Press, Boca Raton, 2023. ISBN 978-0-367-26311-9 978-1-03-244595-3.

[SKA+21]

James Saxon, Julia Koschinsky, Karina Acosta, Vidal Anguiano, Luc Anselin, and Sergio Rey. An open software environment to make spatial access metrics more accessible. Journal of Computational Social Science, June 2021. doi:10.1007/s42001-021-00126-8.

[WKR19]

Levi J. Wolf, Elijah Knaap, and Sergio Rey. Geosilhouettes: Geographical measures of cluster fit. Environment and Planning B: Urban Analytics and City Science, 2019. doi:10.1177/2399808319875752.

[YFL+19]

Hanchen Yu, Alexander Stewart Fotheringham, Ziqi Li, Taylor Oshan, Wei Kang, and Levi John Wolf. Inference in multiscale geographically weighted regression. Geographical Analysis, 2019. URL: https://onlinelibrary.wiley.com/doi/abs/10.1111/gean.12189, arXiv:https://onlinelibrary.wiley.com/doi/pdf/10.1111/gean.12189, doi:10.1111/gean.12189.